@@ -2,17 +2,17 @@
 
 from .db import DatabaseSnapshot, IgnoreConfig, SnapshotDiff
 from .code import TASK_SUCCESSFUL_SCORE, TASK_FAILED_SCORE
-from .decorator import (
+from .verifier import (
     verifier,
     SyncVerifierFunction,
 )
 
 __all__ = [
     "DatabaseSnapshot",
-    "IgnoreConfig", 
+    "IgnoreConfig",
     "SnapshotDiff",
     "TASK_SUCCESSFUL_SCORE",
     "TASK_FAILED_SCORE",
     "verifier",
     "SyncVerifierFunction",
-]
\ No newline at end of file
+]
